@@ -422,7 +422,7 @@ run_gene_cor_celltype <- function(data,
 #' @param data A list object containing `data` matrix and `celltype` and `sample` vector. 
 #' @param type The type of dataset, either "scrna", "spatial_t", or "spatial_p".
 #' @param method Type of pathway analysis method, currently support `ssgsea`
-#'  and `aucell`
+#'  and `aucell`, default to `aucell`
 #' @param geneset By default (when the `geneset` argument is not specified),
 #'  we use the 50 hallmark gene set from msigdb.
 #'  The users can also provide their geneset of interest in a list format, with
@@ -468,7 +468,7 @@ run_gene_cor_celltype <- function(data,
 #' @importFrom DelayedMatrixStats colMeans2
 #'
 #' @export
-run_pathway_gsva <- function(data, method = "ssgsea", geneset = NULL,
+run_pathway_gsva <- function(data, method = "aucell", geneset = NULL,
     species = "Homo sapiens",
     type = "scrna", subsample = TRUE, ncores = 1) {
     check_data(data, type)
@@ -685,7 +685,7 @@ run_pathway_prop <- function(data, geneset = NULL,
 #' Generate cell cell communication score
 #' 
 #' @description 
-#' This function calculates the ligand receptor interaction score using SingleCellSignalR. 
+#' This function calculates the ligand receptor interaction score using CellChat
 #' The output features are in the form of celltype a -> celltype b -- ligand 1 -> receptor 2 ,
 #' which indicates the interaction between ligand 1 in celltype a and receptor 2 in celltype b. 
 #' 
@@ -708,19 +708,19 @@ run_pathway_prop <- function(data, geneset = NULL,
 #' data <- as.matrix(data@assays$RNA@data)
 #' 
 #' alldata <- scFeatures:::formatData(data = data, celltype = celltype, sample = sample )
-#' feature_CCI <- run_CCI(alldata, type = "scrna" ,  ncores = 1 )
-#' 
+#' if (requireNamespace("CellChat", quietly = TRUE)) {
+#'   feature_CCI <- run_CCI(alldata, type = "scrna", ncores = 1)
+#' }
 #' @import dplyr
 #' @import DelayedArray
-#' @import SingleCellSignalR
 #' 
 #' @export
-run_CCI <- function( data, type = "scrna" , ncores = 1  ){
+run_CCI <- function( data, type = "scrna" ,  species = "Homo sapiens", ncores = 1  ){
   
   check_data(data, type)
   
   if ( type == "scrna" )  {
-      X <- helper_CCI(data, ncores =  ncores )
+      X <- helper_CCI(data, species = species, ncores =  ncores )
   }
   
   if ( type == "spatial_p" )  {
